==> blancoIBatis-0.0.1-src.zip: src/blanco/valueobject/valueobject/BlancoValueObjectClassStructure.java <==
/*
 * ̃\[XR[h blanco Frameworkɂ莩܂B
 */
package blanco.valueobject.valueobject;

import java.util.List;

/**
 * o[IuWFNg̃NX킷o[IuWFNgNXB̃NX̐ݒƂɃNX܂B
 */
public class BlancoValueObjectClassStructure {
    /**
     * tB[hw肵܂BK{ڂłB
     *
     * tB[h: [name]B
     */
    private String fName;

    /**
     * pbP[Ww肵܂BK{ڂłB
     *
     * tB[h: [package]B
     */
    private String fPackage;

    /**
     * NXJavaDocw肵܂B
     *
     * tB[h: [description]B
     */
    private String fDescription;

    /**
     * NX̃ANZXBʏ publicB
     *
     * tB[h: [access]B
     * ftHg: ["public"]B
     */
    private String fAccess = "public";

    /**
     * ۃNXǂBʏ falseB
     *
     * tB[h: [abstract]B
     * ftHg: [false]B
     */
    private boolean fAbstract = false;

    /**
     * toString\bh𐶐邩ǂB
     *
     * tB[h: [generateToString]B
     * ftHg: [true]B
     */
    private boolean fGenerateToString = true;

    /**
     * tB[h̖Oό`ȂǂB
     *
     * tB[h: [adjustFieldName]B
     * ftHg: [true]B
     */
    private boolean fAdjustFieldName = true;

    /**
     * ftHgl̕ό`ȂǂBȂׂό`𗘗pȂƂ𐄏BvOAPIƂĐۂɂ́ÃtB[h𖾎Iɐݒ肵ĂB
     *
     * tB[h: [adjustDefaultValue]B
     * ftHg: [true]B
     */
    private boolean fAdjustDefaultValue = true;

    /**
     * pNXw肵܂B
     *
     * tB[h: [extends]B
     */
    private String fExtends;

    /**
     * C^tF[X(java.lang.String)̈ꗗB
     *
     * tB[h: [implementsList]B
     * ftHg: [new java.util.ArrayList<java.lang.String>()]B
     */
    private List<java.lang.String> fImplementsList = new java.util.ArrayList<java.lang.String>();

    /**
     * tB[hL郊Xgw肵܂B
     *
     * tB[h: [fieldList]B
     * ftHg: [new java.util.ArrayList<blanco.valueobject.valueobject.BlancoValueObjectFieldStructure>()]B
     */
    private List<blanco.valueobject.valueobject.BlancoValueObjectFieldStructure> fFieldList = new java.util.ArrayList<blanco.valueobject.valueobject.BlancoValueObjectFieldStructure>();

    /**
     * tB[h [name] ̒lݒ肵܂B
     *
     * tB[h̐: [tB[hw肵܂BK{ڂłB]B
     *
     * @param argName tB[h[name]ɐݒ肷lB
     */
    public void setName(final String argName) {
        fName = argName;
    }

    /**
     * tB[h [name] ̒l擾܂B
     *
     * tB[h̐: [tB[hw肵܂BK{ڂłB]B
     *
     * @return tB[h[name]擾lB
     */
    public String getName() {
        return fName;
    }

    /**
     * tB[h [package] ̒lݒ肵܂B
     *
     * tB[h̐: [pbP[Ww肵܂BK{ڂłB]B
     *
     * @param argPackage tB[h[package]ɐݒ肷lB
     */
    public void setPackage(final String argPackage) {
        fPackage = argPackage;
    }

    /**
     * tB[h [package] ̒l擾܂B
     *
     * tB[h̐: [pbP[Ww肵܂BK{ڂłB]B
     *
     * @return tB[h[package]擾lB
     */
    public String getPackage() {
        return fPackage;
    }

    /**
     * tB[h [description] ̒lݒ肵܂B
     *
     * tB[h̐: [NXJavaDocw肵܂B]B
     *
     * @param argDescription tB[h[description]ɐݒ肷lB
     */
    public void setDescription(final String argDescription) {
        fDescription = argDescription;
    }

    /**
     * tB[h [description] ̒l擾܂B
     *
     * tB[h̐: [NXJavaDocw肵܂B]B
     *
     * @return tB[h[description]擾lB
     */
    public String getDescription() {
        return fDescription;
    }

    /**
     * tB[h [access] ̒lݒ肵܂B
     *
     * tB[h̐: [NX̃ANZXBʏ publicB]B
     *
     * @param argAccess tB[h[access]ɐݒ肷lB
     */
    public void setAccess(final String argAccess) {
        fAccess = argAccess;
    }

    /**
     * tB[h [access] ̒l擾܂B
     *
     * tB[h̐: [NX̃ANZXBʏ publicB]B
     * ftHg: ["public"]B
     *
     * @return tB[h[access]擾lB
     */
    public String getAccess() {
        return fAccess;
    }

    /**
     * tB[h [abstract] ̒lݒ肵܂B
     *
     * tB[h̐: [ۃNXǂBʏ falseB]B
     *
     * @param argAbstract tB[h[abstract]ɐݒ肷lB
     */
    public void setAbstract(final boolean argAbstract) {
        fAbstract = argAbstract;
    }

    /**
     * tB[h [abstract] ̒l擾܂B
     *
     * tB[h̐: [ۃNXǂBʏ falseB]B
     * ftHg: [false]B
     *
     * @return tB[h[abstract]擾lB
     */
    public boolean getAbstract() {
        return fAbstract;
    }

    /**
     * tB[h [generateToString] ̒lݒ肵܂B
     *
     * tB[h̐: [toString\bh𐶐邩ǂB]B
     *
     * @param argGenerateToString tB[h[generateToString]ɐݒ肷lB
     */
    public void setGenerateToString(final boolean argGenerateToString) {
        fGenerateToString = argGenerateToString;
    }

    /**
     * tB[h [generateToString] ̒l擾܂B
     *
     * tB[h̐: [toString\bh𐶐邩ǂB]B
     * ftHg: [true]B
     *
     * @return tB[h[generateToString]擾lB
     */
    public boolean getGenerateToString() {
        return fGenerateToString;
    }

    /**
     * tB[h [adjustFieldName] ̒lݒ肵܂B
     *
     * tB[h̐: [tB[h̖Oό`ȂǂB]B
     *
     * @param argAdjustFieldName tB[h[adjustFieldName]ɐݒ肷lB
     */
    public void setAdjustFieldName(final boolean argAdjustFieldName) {
        fAdjustFieldName = argAdjustFieldName;
    }

    /**
     * tB[h [adjustFieldName] ̒l擾܂B
     *
     * tB[h̐: [tB[h̖Oό`ȂǂB]B
     * ftHg: [true]B
     *
     * @return tB[h[adjustFieldName]擾lB
     */
    public boolean getAdjustFieldName() {
        return fAdjustFieldName;
    }

    /**
     * tB[h [adjustDefaultValue] ̒lݒ肵܂B
     *
     * tB[h̐: [ftHgl̕ό`ȂǂBȂׂό`𗘗pȂƂ𐄏BvOAPIƂĐۂɂ́ÃtB[h𖾎Iɐݒ肵ĂB]B
     *
     * @param argAdjustDefaultValue tB[h[adjustDefaultValue]ɐݒ肷lB
     */
    public void setAdjustDefaultValue(final boolean argAdjustDefaultValue) {
        fAdjustDefaultValue = argAdjustDefaultValue;
    }

    /**
     * tB[h [adjustDefaultValue] ̒l擾܂B
     *
     * tB[h̐: [ftHgl̕ό`ȂǂBȂׂό`𗘗pȂƂ𐄏BvOAPIƂĐۂɂ́ÃtB[h𖾎Iɐݒ肵ĂB]B
     * ftHg: [true]B
     *
     * @return tB[h[adjustDefaultValue]擾lB
     */
    public boolean getAdjustDefaultValue() {
        return fAdjustDefaultValue;
    }

    /**
     * tB[h [extends] ̒lݒ肵܂B
     *
     * tB[h̐: [pNXw肵܂B]B
     *
     * @param argExtends tB[h[extends]ɐݒ肷lB
     */
    public void setExtends(final String argExtends) {
        fExtends = argExtends;
    }

    /**
     * tB[h [extends] ̒l擾܂B
     *
     * tB[h̐: [pNXw肵܂B]B
     *
     * @return tB[h[extends]擾lB
     */
    public String getExtends() {
        return fExtends;
    }

    /**
     * tB[h [implementsList] ̒lݒ肵܂B
     *
     * tB[h̐: [C^tF[X(java.lang.String)̈ꗗB]B
     *
     * @param argImplementsList tB[h[implementsList]ɐݒ肷lB
     */
    public void setImplementsList(final List<java.lang.String> argImplementsList) {
        fImplementsList = argImplementsList;
    }

    /**
     * tB[h [implementsList] ̒l擾܂B
     *
     * tB[h̐: [C^tF[X(java.lang.String)̈ꗗB]B
     * ftHg: [new java.util.ArrayList<java.lang.String>()]B
     *
     * @return tB[h[implementsList]擾lB
     */
    public List<java.lang.String> getImplementsList() {
        return fImplementsList;
    }

    /**
     * tB[h [fieldList] ̒lݒ肵܂B
     *
     * tB[h̐: [tB[hL郊Xgw肵܂B]B
     *
     * @param argFieldList tB[h[fieldList]ɐݒ肷lB
     */
    public void setFieldList(final List<blanco.valueobject.valueobject.BlancoValueObjectFieldStructure> argFieldList) {
        fFieldList = argFieldList;
    }

    /**
     * tB[h [fieldList] ̒l擾܂B
     *
     * tB[h̐: [tB[hL郊Xgw肵܂B]B
     * ftHg: [new java.util.ArrayList<blanco.valueobject.valueobject.BlancoValueObjectFieldStructure>()]B
     *
     * @return tB[h[fieldList]擾lB
     */
    public List<blanco.valueobject.valueobject.BlancoValueObjectFieldStructure> getFieldList() {
        return fFieldList;
    }

    /**
     * ̃o[IuWFNg̕\擾܂B
     *
     * gp̒
     * <UL>
     * <LI>IuWFNg̃V[͈͂̂ݕ񉻂̏ΏۂƂȂ܂B
     * <LI>IuWFNgzQƂĂꍇɂ́Ã\bh͎gȂłB
     * </UL>
     *
     * @return o[IuWFNg̕\B
     */
    public String toString() {
        final StringBuffer buf = new StringBuffer();
        buf.append("blanco.valueobject.valueobject.BlancoValueObjectClassStructure[");
        buf.append("name=" + fName);
        buf.append(",package=" + fPackage);
        buf.append(",description=" + fDescription);
        buf.append(",access=" + fAccess);
        buf.append(",abstract=" + fAbstract);
        buf.append(",generateToString=" + fGenerateToString);
        buf.append(",adjustFieldName=" + fAdjustFieldName);
        buf.append(",adjustDefaultValue=" + fAdjustDefaultValue);
        buf.append(",extends=" + fExtends);
        buf.append(",implementsList=" + fImplementsList);
        buf.append(",fieldList=" + fFieldList);
        buf.append("]");
        return buf.toString();
    }
}

==> blancoIBatis-0.0.3-src.zip: src/blanco/valueobject/valueobject/BlancoValueObjectClassStructure.java <==
/*
 * ̃\[XR[h blanco Frameworkɂ莩܂B
 */
package blanco.valueobject.valueobject;

import java.util.List;

/**
 * o[IuWFNg̃NX킷o[IuWFNgNXB̃NX̐ݒƂɃNX܂B
 */
public class BlancoValueObjectClassStructure {
    /**
     * tB[hw肵܂BK{ڂłB
     *
     * tB[h: [name]B
     */
    private String fName;

    /**
     * pbP[Ww肵܂BK{ڂłB
     *
     * tB[h: [package]B
     */
    private String fPackage;

    /**
     * NX̐łB
     *
     * tB[h: [description]B
     */
    private String fDescription;

    /**
     * NX̕⏕łBQƃGR[hς݂̒li[ĂB
     *
     * tB[h: [descriptionList]B
     * ftHg: [new java.util.ArrayList<java.lang.String>()]B
     */
    private List<java.lang.String> fDescriptionList = new java.util.ArrayList<java.lang.String>();

    /**
     * NX̃ANZXBʏ publicB
     *
     * tB[h: [access]B
     * ftHg: ["public"]B
     */
    private String fAccess = "public";

    /**
     * ۃNXǂBʏ falseB
     *
     * tB[h: [abstract]B
     * ftHg: [false]B
     */
    private boolean fAbstract = false;

    /**
     * toString\bh𐶐邩ǂB
     *
     * tB[h: [generateToString]B
     * ftHg: [true]B
     */
    private boolean fGenerateToString = true;

    /**
     * tB[h̖Oό`ȂǂB
     *
     * tB[h: [adjustFieldName]B
     * ftHg: [true]B
     */
    private boolean fAdjustFieldName = true;

    /**
     * ftHgl̕ό`ȂǂBȂׂό`𗘗pȂƂ𐄏BvOAPIƂĐۂɂ́ÃtB[h𖾎Iɐݒ肵ĂB
     *
     * tB[h: [adjustDefaultValue]B
     * ftHg: [true]B
     */
    private boolean fAdjustDefaultValue = true;

    /**
     * pNXw肵܂B
     *
     * tB[h: [extends]B
     */
    private String fExtends;

    /**
     * C^tF[X(java.lang.String)̈ꗗB
     *
     * tB[h: [implementsList]B
     * ftHg: [new java.util.ArrayList<java.lang.String>()]B
     */
    private List<java.lang.String> fImplementsList = new java.util.ArrayList<java.lang.String>();

    /**
     * tB[hL郊Xgw肵܂B
     *
     * tB[h: [fieldList]B
     * ftHg: [new java.util.ArrayList<blanco.valueobject.valueobject.BlancoValueObjectFieldStructure>()]B
     */
    private List<blanco.valueobject.valueobject.BlancoValueObjectFieldStructure> fFieldList = new java.util.ArrayList<blanco.valueobject.valueobject.BlancoValueObjectFieldStructure>();

    /**
     * tB[h [name] ̒lݒ肵܂B
     *
     * tB[h̐: [tB[hw肵܂BK{ڂłB]B
     *
     * @param argName tB[h[name]ɐݒ肷lB
     */
    public void setName(final String argName) {
        fName = argName;
    }

    /**
     * tB[h [name] ̒l擾܂B
     *
     * tB[h̐: [tB[hw肵܂BK{ڂłB]B
     *
     * @return tB[h[name]擾lB
     */
    public String getName() {
        return fName;
    }

    /**
     * tB[h [package] ̒lݒ肵܂B
     *
     * tB[h̐: [pbP[Ww肵܂BK{ڂłB]B
     *
     * @param argPackage tB[h[package]ɐݒ肷lB
     */
    public void setPackage(final String argPackage) {
        fPackage = argPackage;
    }

    /**
     * tB[h [package] ̒l擾܂B
     *
     * tB[h̐: [pbP[Ww肵܂BK{ڂłB]B
     *
     * @return tB[h[package]擾lB
     */
    public String getPackage() {
        return fPackage;
    }

    /**
     * tB[h [description] ̒lݒ肵܂B
     *
     * tB[h̐: [NX̐łB]B
     *
     * @param argDescription tB[h[description]ɐݒ肷lB
     */
    public void setDescription(final String argDescription) {
        fDescription = argDescription;
    }

    /**
     * tB[h [description] ̒l擾܂B
     *
     * tB[h̐: [NX̐łB]B
     *
     * @return tB[h[description]擾lB
     */
    public String getDescription() {
        return fDescription;
    }

    /**
     * tB[h [descriptionList] ̒lݒ肵܂B
     *
     * tB[h̐: [NX̕⏕łBQƃGR[hς݂̒li[ĂB]B
     *
     * @param argDescriptionList tB[h[descriptionList]ɐݒ肷lB
     */
    public void setDescriptionList(final List<java.lang.String> argDescriptionList) {
        fDescriptionList = argDescriptionList;
    }

    /**
     * tB[h [descriptionList] ̒l擾܂B
     *
     * tB[h̐: [NX̕⏕łBQƃGR[hς݂̒li[ĂB]B
     * ftHg: [new java.util.ArrayList<java.lang.String>()]B
     *
     * @return tB[h[descriptionList]擾lB
     */
    public List<java.lang.String> getDescriptionList() {
        return fDescriptionList;
    }

    /**
     * tB[h [access] ̒lݒ肵܂B
     *
     * tB[h̐: [NX̃ANZXBʏ publicB]B
     *
     * @param argAccess tB[h[access]ɐݒ肷lB
     */
    public void setAccess(final String argAccess) {
        fAccess = argAccess;
    }

    /**
     * tB[h [access] ̒l擾܂B
     *
     * tB[h̐: [NX̃ANZXBʏ publicB]B
     * ftHg: ["public"]B
     *
     * @return tB[h[access]擾lB
     */
    public String getAccess() {
        return fAccess;
    }

    /**
     * tB[h [abstract] ̒lݒ肵܂B
     *
     * tB[h̐: [ۃNXǂBʏ falseB]B
     *
     * @param argAbstract tB[h[abstract]ɐݒ肷lB
     */
    public void setAbstract(final boolean argAbstract) {
        fAbstract = argAbstract;
    }

    /**
     * tB[h [abstract] ̒l擾܂B
     *
     * tB[h̐: [ۃNXǂBʏ falseB]B
     * ftHg: [false]B
     *
     * @return tB[h[abstract]擾lB
     */
    public boolean getAbstract() {
        return fAbstract;
    }

    /**
     * tB[h [generateToString] ̒lݒ肵܂B
     *
     * tB[h̐: [toString\bh𐶐邩ǂB]B
     *
     * @param argGenerateToString tB[h[generateToString]ɐݒ肷lB
     */
    public void setGenerateToString(final boolean argGenerateToString) {
        fGenerateToString = argGenerateToString;
    }

    /**
     * tB[h [generateToString] ̒l擾܂B
     *
     * tB[h̐: [toString\bh𐶐邩ǂB]B
     * ftHg: [true]B
     *
     * @return tB[h[generateToString]擾lB
     */
    public boolean getGenerateToString() {
        return fGenerateToString;
    }

    /**
     * tB[h [adjustFieldName] ̒lݒ肵܂B
     *
     * tB[h̐: [tB[h̖Oό`ȂǂB]B
     *
     * @param argAdjustFieldName tB[h[adjustFieldName]ɐݒ肷lB
     */
    public void setAdjustFieldName(final boolean argAdjustFieldName) {
        fAdjustFieldName = argAdjustFieldName;
    }

    /**
     * tB[h [adjustFieldName] ̒l擾܂B
     *
     * tB[h̐: [tB[h̖Oό`ȂǂB]B
     * ftHg: [true]B
     *
     * @return tB[h[adjustFieldName]擾lB
     */
    public boolean getAdjustFieldName() {
        return fAdjustFieldName;
    }

    /**
     * tB[h [adjustDefaultValue] ̒lݒ肵܂B
     *
     * tB[h̐: [ftHgl̕ό`ȂǂBȂׂό`𗘗pȂƂ𐄏BvOAPIƂĐۂɂ́ÃtB[h𖾎Iɐݒ肵ĂB]B
     *
     * @param argAdjustDefaultValue tB[h[adjustDefaultValue]ɐݒ肷lB
     */
    public void setAdjustDefaultValue(final boolean argAdjustDefaultValue) {
        fAdjustDefaultValue = argAdjustDefaultValue;
    }

    /**
     * tB[h [adjustDefaultValue] ̒l擾܂B
     *
     * tB[h̐: [ftHgl̕ό`ȂǂBȂׂό`𗘗pȂƂ𐄏BvOAPIƂĐۂɂ́ÃtB[h𖾎Iɐݒ肵ĂB]B
     * ftHg: [true]B
     *
     * @return tB[h[adjustDefaultValue]擾lB
     */
    public boolean getAdjustDefaultValue() {
        return fAdjustDefaultValue;
    }

    /**
     * tB[h [extends] ̒lݒ肵܂B
     *
     * tB[h̐: [pNXw肵܂B]B
     *
     * @param argExtends tB[h[extends]ɐݒ肷lB
     */
    public void setExtends(final String argExtends) {
        fExtends = argExtends;
    }

    /**
     * tB[h [extends] ̒l擾܂B
     *
     * tB[h̐: [pNXw肵܂B]B
     *
     * @return tB[h[extends]擾lB
     */
    public String getExtends() {
        return fExtends;
    }

    /**
     * tB[h [implementsList] ̒lݒ肵܂B
     *
     * tB[h̐: [C^tF[X(java.lang.String)̈ꗗB]B
     *
     * @param argImplementsList tB[h[implementsList]ɐݒ肷lB
     */
    public void setImplementsList(final List<java.lang.String> argImplementsList) {
        fImplementsList = argImplementsList;
    }

    /**
     * tB[h [implementsList] ̒l擾܂B
     *
     * tB[h̐: [C^tF[X(java.lang.String)̈ꗗB]B
     * ftHg: [new java.util.ArrayList<java.lang.String>()]B
     *
     * @return tB[h[implementsList]擾lB
     */
    public List<java.lang.String> getImplementsList() {
        return fImplementsList;
    }

    /**
     * tB[h [fieldList] ̒lݒ肵܂B
     *
     * tB[h̐: [tB[hL郊Xgw肵܂B]B
     *
     * @param argFieldList tB[h[fieldList]ɐݒ肷lB
     */
    public void setFieldList(final List<blanco.valueobject.valueobject.BlancoValueObjectFieldStructure> argFieldList) {
        fFieldList = argFieldList;
    }

    /**
     * tB[h [fieldList] ̒l擾܂B
     *
     * tB[h̐: [tB[hL郊Xgw肵܂B]B
     * ftHg: [new java.util.ArrayList<blanco.valueobject.valueobject.BlancoValueObjectFieldStructure>()]B
     *
     * @return tB[h[fieldList]擾lB
     */
    public List<blanco.valueobject.valueobject.BlancoValueObjectFieldStructure> getFieldList() {
        return fFieldList;
    }

    /**
     * ̃o[IuWFNg̕\擾܂B
     *
     * gp̒
     * <UL>
     * <LI>IuWFNg̃V[͈͂̂ݕ񉻂̏ΏۂƂȂ܂B
     * <LI>IuWFNgzQƂĂꍇɂ́Ã\bh͎gȂłB
     * </UL>
     *
     * @return o[IuWFNg̕\B
     */
    public String toString() {
        final StringBuffer buf = new StringBuffer();
        buf.append("blanco.valueobject.valueobject.BlancoValueObjectClassStructure[");
        buf.append("name=" + fName);
        buf.append(",package=" + fPackage);
        buf.append(",description=" + fDescription);
        buf.append(",descriptionList=" + fDescriptionList);
        buf.append(",access=" + fAccess);
        buf.append(",abstract=" + fAbstract);
        buf.append(",generateToString=" + fGenerateToString);
        buf.append(",adjustFieldName=" + fAdjustFieldName);
        buf.append(",adjustDefaultValue=" + fAdjustDefaultValue);
        buf.append(",extends=" + fExtends);
        buf.append(",implementsList=" + fImplementsList);
        buf.append(",fieldList=" + fFieldList);
        buf.append("]");
        return buf.toString();
    }
}
